/** CommentsWidget is the main entity of CommentsWidgetRegistry that can be used for lorem ipsum dolor */
interface CommentsWidget {
    /**
     * CommentsWidget ID
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Widget category ID
     * @format GUID
     */
    categoryId?: string;
    /**
     * Widget resource ID
     * @minLength 1
     * @maxLength 128
     */
    resourceId?: string;
    /** Path to widget location */
    urlPath?: string;
    /** Represents the current state of an item. Each time the item is modified, its `revision` changes. for an update operation to succeed, you MUST pass the latest revision */
    revision?: string | null;
    /**
     * Represents the time this CommentsResource was created
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Represents the time this CommentsResource was last updated
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Component ID of the widget to which the category is attached to
     * @maxLength 300
     */
    componentId?: string | null;
    /** Count indicating how many published comments exist in category and resource */
    commentCount?: number | null;
}
interface RegisterCommentsWidgetRequest {
    /**
     * Widget category ID
     * @format GUID
     */
    categoryId: string;
    /**
     * Widget resource ID
     * @minLength 1
     * @maxLength 128
     */
    resourceId: string;
    /**
     * Deprecated field
     * @minLength 1
     * @maxLength 128
     */
    componentId?: string;
    /**
     * Dynamic page tittle, if the widget is inside a dynamic page
     * @maxLength 300
     */
    dynamicPageTitle?: string | null;
    /**
     * PageId of the page, which contains the widget
     * @minLength 1
     * @maxLength 300
     */
    pageId?: string | null;
    /**
     * Page Url, provided by the client
     * @maxLength 500
     */
    urlPath?: string | null;
}
interface RegisterCommentsWidgetResponse {
    /** The registered CommentsWidget */
    commentsWidget?: CommentsWidget;
}
interface QueryCommentsWidgetResourcesRequest {
    /** Cursor query */
    query: CursorQuery;
}
interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /**
     * Cursor paging options.
     *
     * Learn more about [cursor paging](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#cursor-paging).
     */
    cursorPaging?: CursorPaging;
    /**
     * Filter object.
     *
     * Learn more about the [filter section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-filter-section).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object.
     *
     * Learn more about the [sort section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-sort-section).
     * @maxSize 5
     */
    sort?: Sorting[];
}
/** @oneof */
interface CursorQueryPagingMethodOneOf {
    /**
     * Cursor paging options.
     *
     * Learn more about [cursor paging](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#cursor-paging).
     */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface QueryCommentsWidgetResourcesResponse {
    /**
     * List of resources
     * @minLength 1
     * @maxLength 128
     * @maxSize 100
     */
    resourceIds?: string[];
    /** Paging metadata */
    pagingMetadata?: CursorPagingMetadata;
}
interface CursorPagingMetadata {
    /** Number of items returned in current page. */
    count?: number | null;
    /** Cursor strings that point to the next page, previous page, or both. */
    cursors?: Cursors;
    /**
     * Whether there are more pages to retrieve following the current page.
     *
     * + `true`: Another page of results can be retrieved.
     * + `false`: This is the last page.
     */
    hasNext?: boolean | null;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface CreateCommentsWidgetRequest {
    /** CommentsWidget to be created */
    commentsWidget: CommentsWidget;
}
interface CreateCommentsWidgetResponse {
    /** The created CommentsWidget */
    commentsWidget?: CommentsWidget;
}
interface GetCommentsWidgetRequest {
    /**
     * Id of the CommentsWidget to retrieve
     * @format GUID
     */
    commentsWidgetId: string;
}
interface GetCommentsWidgetResponse {
    /** The retrieved CommentsWidget */
    commentsWidget?: CommentsWidget;
}
interface UpdateCommentsWidgetRequest {
    /** CommentsWidget to be updated, may be partial */
    commentsWidget: CommentsWidget;
}
interface UpdateCommentsWidgetResponse {
    /** The updated CommentsWidget */
    commentsWidget?: CommentsWidget;
}
interface DeleteCommentsWidgetRequest {
    /**
     * Id of the CommentsWidget to delete
     * @format GUID
     */
    commentsWidgetId: string;
    /** The revision of the CommentsWidget */
    revision?: string;
}
interface DeleteCommentsWidgetResponse {
}
interface QueryCommentsWidgetRequest {
    /** WQL expression */
    query: QueryV2;
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object.
     *
     * Learn more about the [filter section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-filter-section).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object.
     *
     * Learn more about the [sort section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-sort-section).
     */
    sort?: Sorting[];
    /** Array of projected fields. A list of specific field names to return. If `fieldsets` are also specified, the union of `fieldsets` and `fields` is returned. */
    fields?: string[];
    /** Array of named, predefined sets of projected fields. A array of predefined named sets of fields to be returned. Specifying multiple `fieldsets` will return the union of fields from all sets. If `fields` are also specified, the union of `fieldsets` and `fields` is returned. */
    fieldsets?: string[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface QueryCommentsWidgetResponse {
    /** The retrieved CommentsWidgets */
    commentsWidgets?: CommentsWidget[];
    /** Paging metadata */
    metadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface Empty {
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface CommentsWidgetCreatedEnvelope {
    entity: CommentsWidget;
    metadata: EventMetadata;
}
interface CommentsWidgetDeletedEnvelope {
    metadata: EventMetadata;
}
interface CommentsWidgetUpdatedEnvelope {
    entity: CommentsWidget;
    metadata: EventMetadata;
}
interface RegisterCommentsWidgetOptions {
    /**
     * Widget resource ID
     * @minLength 1
     * @maxLength 128
     */
    resourceId: string;
    /**
     * Deprecated field
     * @minLength 1
     * @maxLength 128
     */
    componentId?: string;
    /**
     * Dynamic page tittle, if the widget is inside a dynamic page
     * @maxLength 300
     */
    dynamicPageTitle?: string | null;
    /**
     * PageId of the page, which contains the widget
     * @minLength 1
     * @maxLength 300
     */
    pageId?: string | null;
    /**
     * Page Url, provided by the client
     * @maxLength 500
     */
    urlPath?: string | null;
}
interface UpdateCommentsWidget {
    /**
     * CommentsWidget ID
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Widget category ID
     * @format GUID
     */
    categoryId?: string;
    /**
     * Widget resource ID
     * @minLength 1
     * @maxLength 128
     */
    resourceId?: string;
    /** Path to widget location */
    urlPath?: string;
    /** Represents the current state of an item. Each time the item is modified, its `revision` changes. for an update operation to succeed, you MUST pass the latest revision */
    revision?: string | null;
    /**
     * Represents the time this CommentsResource was created
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Represents the time this CommentsResource was last updated
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Component ID of the widget to which the category is attached to
     * @maxLength 300
     */
    componentId?: string | null;
    /** Count indicating how many published comments exist in category and resource */
    commentCount?: number | null;
}
interface DeleteCommentsWidgetOptions {
    /** The revision of the CommentsWidget */
    revision?: string;
}
interface QueryCursorResult {
    cursors: Cursors;
    hasNext: () => boolean;
    hasPrev: () => boolean;
    length: number;
    pageSize: number;
}
interface CommentsWidgetsQueryResult extends QueryCursorResult {
    items: CommentsWidget[];
    query: CommentsWidgetsQueryBuilder;
    next: () => Promise<CommentsWidgetsQueryResult>;
    prev: () => Promise<CommentsWidgetsQueryResult>;
}
interface CommentsWidgetsQueryBuilder {
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    eq: (propertyName: '_id' | 'categoryId' | 'resourceId' | 'urlPath' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount', value: any) => CommentsWidgetsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ne: (propertyName: '_id' | 'categoryId' | 'resourceId' | 'urlPath' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount', value: any) => CommentsWidgetsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ge: (propertyName: '_id' | 'categoryId' | 'resourceId' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount', value: any) => CommentsWidgetsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    gt: (propertyName: '_id' | 'categoryId' | 'resourceId' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount', value: any) => CommentsWidgetsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    le: (propertyName: '_id' | 'categoryId' | 'resourceId' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount', value: any) => CommentsWidgetsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    lt: (propertyName: '_id' | 'categoryId' | 'resourceId' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount', value: any) => CommentsWidgetsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `string`.
     * @param string - String to compare against. Case-insensitive.
     * @documentationMaturity preview
     */
    startsWith: (propertyName: '_id' | 'categoryId' | 'resourceId' | 'componentId', value: string) => CommentsWidgetsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     * @documentationMaturity preview
     */
    hasSome: (propertyName: '_id' | 'categoryId' | 'resourceId' | 'urlPath' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount', value: any[]) => CommentsWidgetsQueryBuilder;
    /** @documentationMaturity preview */
    in: (propertyName: '_id' | 'categoryId' | 'resourceId' | 'urlPath' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount', value: any) => CommentsWidgetsQueryBuilder;
    /** @documentationMaturity preview */
    exists: (propertyName: '_id' | 'categoryId' | 'resourceId' | 'urlPath' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount', value: boolean) => CommentsWidgetsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    ascending: (...propertyNames: Array<'_id' | 'categoryId' | 'resourceId' | 'urlPath' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount'>) => CommentsWidgetsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    descending: (...propertyNames: Array<'_id' | 'categoryId' | 'resourceId' | 'urlPath' | '_createdDate' | '_updatedDate' | 'componentId' | 'commentCount'>) => CommentsWidgetsQueryBuilder;
    /** @param limit - Number of items to return, which is also the `pageSize` of the results object.
     * @documentationMaturity preview
     */
    limit: (limit: number) => CommentsWidgetsQueryBuilder;
    /** @param cursor - A pointer to specific record
     * @documentationMaturity preview
     */
    skipTo: (cursor: string) => CommentsWidgetsQueryBuilder;
    /** @documentationMaturity preview */
    find: () => Promise<CommentsWidgetsQueryResult>;
}

export { type DomainEventBodyOneOf as A, type RestoreInfo as B, type CursorQuery as C, type DeleteCommentsWidgetOptions as D, type EntityCreatedEvent as E, type EntityUpdatedEvent as F, type GetCommentsWidgetRequest as G, type EntityDeletedEvent as H, type ActionEvent as I, type Empty as J, type IdentificationData as K, type IdentificationDataIdOneOf as L, type MessageEnvelope as M, type BaseEventMetadata as N, type EventMetadata as O, type Paging as P, type QueryCommentsWidgetResourcesResponse as Q, type RegisterCommentsWidgetOptions as R, SortOrder as S, type CommentsWidgetsQueryResult as T, type UpdateCommentsWidget as U, WebhookIdentityType as W, type RegisterCommentsWidgetResponse as a, type CommentsWidget as b, type CommentsWidgetsQueryBuilder as c, type CommentsWidgetCreatedEnvelope as d, type CommentsWidgetDeletedEnvelope as e, type CommentsWidgetUpdatedEnvelope as f, type RegisterCommentsWidgetRequest as g, type QueryCommentsWidgetResourcesRequest as h, type CursorQueryPagingMethodOneOf as i, type Sorting as j, type CursorPaging as k, type CursorPagingMetadata as l, type Cursors as m, type CreateCommentsWidgetRequest as n, type CreateCommentsWidgetResponse as o, type GetCommentsWidgetResponse as p, type UpdateCommentsWidgetRequest as q, type UpdateCommentsWidgetResponse as r, type DeleteCommentsWidgetRequest as s, type DeleteCommentsWidgetResponse as t, type QueryCommentsWidgetRequest as u, type QueryV2 as v, type QueryV2PagingMethodOneOf as w, type QueryCommentsWidgetResponse as x, type PagingMetadataV2 as y, type DomainEvent as z };
