import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { R as RegisterCommentsWidgetOptions, a as RegisterCommentsWidgetResponse, C as CursorQuery, Q as QueryCommentsWidgetResourcesResponse, b as CommentsWidget, U as UpdateCommentsWidget, D as DeleteCommentsWidgetOptions, c as CommentsWidgetsQueryBuilder, d as CommentsWidgetCreatedEnvelope, e as CommentsWidgetDeletedEnvelope, f as CommentsWidgetUpdatedEnvelope } from './comments-categories-v1-comments-widget-widgets.universal-Bx1_mdks.js';
export { I as ActionEvent, N as BaseEventMetadata, T as CommentsWidgetsQueryResult, n as CreateCommentsWidgetRequest, o as CreateCommentsWidgetResponse, k as CursorPaging, l as CursorPagingMetadata, i as CursorQueryPagingMethodOneOf, m as Cursors, s as DeleteCommentsWidgetRequest, t as DeleteCommentsWidgetResponse, z as DomainEvent, A as DomainEventBodyOneOf, J as Empty, E as EntityCreatedEvent, H as EntityDeletedEvent, F as EntityUpdatedEvent, O as EventMetadata, G as GetCommentsWidgetRequest, p as GetCommentsWidgetResponse, K as IdentificationData, L as IdentificationDataIdOneOf, M as MessageEnvelope, P as Paging, y as PagingMetadataV2, u as QueryCommentsWidgetRequest, h as QueryCommentsWidgetResourcesRequest, x as QueryCommentsWidgetResponse, v as QueryV2, w as QueryV2PagingMethodOneOf, g as RegisterCommentsWidgetRequest, B as RestoreInfo, S as SortOrder, j as Sorting, q as UpdateCommentsWidgetRequest, r as UpdateCommentsWidgetResponse, W as WebhookIdentityType } from './comments-categories-v1-comments-widget-widgets.universal-Bx1_mdks.js';

declare function registerCommentsWidget$1(httpClient: HttpClient): RegisterCommentsWidgetSignature;
interface RegisterCommentsWidgetSignature {
    /**
     * Registers CommentsWidget. Whenever a widget is loaded for the first time or its resourceId changes, it saves the new resource information about the widget
     * @param - Widget category ID
     */
    (categoryId: string, options?: RegisterCommentsWidgetOptions | undefined): Promise<RegisterCommentsWidgetResponse>;
}
declare function queryCommentsWidgetResources$1(httpClient: HttpClient): QueryCommentsWidgetResourcesSignature;
interface QueryCommentsWidgetResourcesSignature {
    /**
     * Returns all registered widget resource ids contained in metaSite
     * @param - Cursor query
     */
    (query: CursorQuery): Promise<QueryCommentsWidgetResourcesResponse>;
}
declare function createCommentsWidget$1(httpClient: HttpClient): CreateCommentsWidgetSignature;
interface CreateCommentsWidgetSignature {
    /**
     * Creates a new CommentsWidget
     * @param - CommentsWidget to be created
     * @returns The created CommentsWidget
     */
    (commentsWidget: CommentsWidget): Promise<CommentsWidget>;
}
declare function getCommentsWidget$1(httpClient: HttpClient): GetCommentsWidgetSignature;
interface GetCommentsWidgetSignature {
    /**
     * Get a CommentsWidget by id
     * @param - Id of the CommentsWidget to retrieve
     * @returns The retrieved CommentsWidget
     */
    (commentsWidgetId: string): Promise<CommentsWidget>;
}
declare function updateCommentsWidget$1(httpClient: HttpClient): UpdateCommentsWidgetSignature;
interface UpdateCommentsWidgetSignature {
    /**
     * Update CommentsWidget, supports partial update
     * Pass the latest `revision` for a successful update
     * @param - CommentsWidget ID
     * @returns The updated CommentsWidget
     */
    (_id: string, commentsWidget: UpdateCommentsWidget): Promise<CommentsWidget>;
}
declare function deleteCommentsWidget$1(httpClient: HttpClient): DeleteCommentsWidgetSignature;
interface DeleteCommentsWidgetSignature {
    /**
     * Delete a CommentsWidget
     * @param - Id of the CommentsWidget to delete
     */
    (commentsWidgetId: string, options?: DeleteCommentsWidgetOptions | undefined): Promise<void>;
}
declare function queryCommentsWidget$1(httpClient: HttpClient): QueryCommentsWidgetSignature;
interface QueryCommentsWidgetSignature {
    /**
     * Query CommentsWidgets using [WQL - Wix Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language)
     */
    (): CommentsWidgetsQueryBuilder;
}
declare const onCommentsWidgetCreated$1: EventDefinition<CommentsWidgetCreatedEnvelope, "wix.comments.categories.v1.comments_widget_created">;
declare const onCommentsWidgetDeleted$1: EventDefinition<CommentsWidgetDeletedEnvelope, "wix.comments.categories.v1.comments_widget_deleted">;
declare const onCommentsWidgetUpdated$1: EventDefinition<CommentsWidgetUpdatedEnvelope, "wix.comments.categories.v1.comments_widget_updated">;

declare const registerCommentsWidget: MaybeContext<BuildRESTFunction<typeof registerCommentsWidget$1> & typeof registerCommentsWidget$1>;
declare const queryCommentsWidgetResources: MaybeContext<BuildRESTFunction<typeof queryCommentsWidgetResources$1> & typeof queryCommentsWidgetResources$1>;
declare const createCommentsWidget: MaybeContext<BuildRESTFunction<typeof createCommentsWidget$1> & typeof createCommentsWidget$1>;
declare const getCommentsWidget: MaybeContext<BuildRESTFunction<typeof getCommentsWidget$1> & typeof getCommentsWidget$1>;
declare const updateCommentsWidget: MaybeContext<BuildRESTFunction<typeof updateCommentsWidget$1> & typeof updateCommentsWidget$1>;
declare const deleteCommentsWidget: MaybeContext<BuildRESTFunction<typeof deleteCommentsWidget$1> & typeof deleteCommentsWidget$1>;
declare const queryCommentsWidget: MaybeContext<BuildRESTFunction<typeof queryCommentsWidget$1> & typeof queryCommentsWidget$1>;
/** */
declare const onCommentsWidgetCreated: BuildEventDefinition<typeof onCommentsWidgetCreated$1>;
/** */
declare const onCommentsWidgetDeleted: BuildEventDefinition<typeof onCommentsWidgetDeleted$1>;
/** */
declare const onCommentsWidgetUpdated: BuildEventDefinition<typeof onCommentsWidgetUpdated$1>;

export { CommentsWidget, CommentsWidgetCreatedEnvelope, CommentsWidgetDeletedEnvelope, CommentsWidgetUpdatedEnvelope, CommentsWidgetsQueryBuilder, CursorQuery, DeleteCommentsWidgetOptions, QueryCommentsWidgetResourcesResponse, RegisterCommentsWidgetOptions, RegisterCommentsWidgetResponse, UpdateCommentsWidget, createCommentsWidget, deleteCommentsWidget, getCommentsWidget, onCommentsWidgetCreated, onCommentsWidgetDeleted, onCommentsWidgetUpdated, queryCommentsWidget, queryCommentsWidgetResources, registerCommentsWidget, updateCommentsWidget };
