import { g as RegisterCommentsWidgetRequest$1, a as RegisterCommentsWidgetResponse$1, h as QueryCommentsWidgetResourcesRequest$1, Q as QueryCommentsWidgetResourcesResponse$1, n as CreateCommentsWidgetRequest$1, o as CreateCommentsWidgetResponse$1, G as GetCommentsWidgetRequest$1, p as GetCommentsWidgetResponse$1, q as UpdateCommentsWidgetRequest$1, r as UpdateCommentsWidgetResponse$1, s as DeleteCommentsWidgetRequest$1, t as DeleteCommentsWidgetResponse$1, u as QueryCommentsWidgetRequest$1, x as QueryCommentsWidgetResponse$1 } from './comments-categories-v1-comments-widget-widgets.universal-Bx1_mdks.mjs';

/** CommentsWidget is the main entity of CommentsWidgetRegistry that can be used for lorem ipsum dolor */
interface CommentsWidget {
    /**
     * CommentsWidget ID
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Widget category ID
     * @format GUID
     */
    categoryId?: string;
    /**
     * Widget resource ID
     * @minLength 1
     * @maxLength 128
     */
    resourceId?: string;
    /** Path to widget location */
    urlPath?: PageUrlV2;
    /** Represents the current state of an item. Each time the item is modified, its `revision` changes. for an update operation to succeed, you MUST pass the latest revision */
    revision?: string | null;
    /**
     * Represents the time this CommentsResource was created
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Represents the time this CommentsResource was last updated
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Component ID of the widget to which the category is attached to
     * @maxLength 300
     */
    componentId?: string | null;
    /** Count indicating how many published comments exist in category and resource */
    commentCount?: number | null;
}
interface PageUrlV2 {
    /** The relative path for the page within the site. For example, `/product-page/a-product`. */
    relativePath?: string;
    /** The page's full URL. For example, `https://mysite.com/product-page/a-product`. */
    url?: string | null;
}
interface RegisterCommentsWidgetRequest {
    /**
     * Widget category ID
     * @format GUID
     */
    categoryId: string;
    /**
     * Widget resource ID
     * @minLength 1
     * @maxLength 128
     */
    resourceId: string;
    /**
     * Deprecated field
     * @minLength 1
     * @maxLength 128
     */
    componentId?: string;
    /**
     * Dynamic page tittle, if the widget is inside a dynamic page
     * @maxLength 300
     */
    dynamicPageTitle?: string | null;
    /**
     * PageId of the page, which contains the widget
     * @minLength 1
     * @maxLength 300
     */
    pageId?: string | null;
    /**
     * Page Url, provided by the client
     * @maxLength 500
     */
    urlPath?: string | null;
}
interface RegisterCommentsWidgetResponse {
    /** The registered CommentsWidget */
    commentsWidget?: CommentsWidget;
}
interface QueryCommentsWidgetResourcesRequest {
    /** Cursor query */
    query: CursorQuery;
}
interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /**
     * Cursor paging options.
     *
     * Learn more about [cursor paging](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#cursor-paging).
     */
    cursorPaging?: CursorPaging;
    /**
     * Filter object.
     *
     * Learn more about the [filter section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-filter-section).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object.
     *
     * Learn more about the [sort section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-sort-section).
     * @maxSize 5
     */
    sort?: Sorting[];
}
/** @oneof */
interface CursorQueryPagingMethodOneOf {
    /**
     * Cursor paging options.
     *
     * Learn more about [cursor paging](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#cursor-paging).
     */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface QueryCommentsWidgetResourcesResponse {
    /**
     * List of resources
     * @minLength 1
     * @maxLength 128
     * @maxSize 100
     */
    resourceIds?: string[];
    /** Paging metadata */
    pagingMetadata?: CursorPagingMetadata;
}
interface CursorPagingMetadata {
    /** Number of items returned in current page. */
    count?: number | null;
    /** Cursor strings that point to the next page, previous page, or both. */
    cursors?: Cursors;
    /**
     * Whether there are more pages to retrieve following the current page.
     *
     * + `true`: Another page of results can be retrieved.
     * + `false`: This is the last page.
     */
    hasNext?: boolean | null;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface CreateCommentsWidgetRequest {
    /** CommentsWidget to be created */
    commentsWidget: CommentsWidget;
}
interface CreateCommentsWidgetResponse {
    /** The created CommentsWidget */
    commentsWidget?: CommentsWidget;
}
interface GetCommentsWidgetRequest {
    /**
     * Id of the CommentsWidget to retrieve
     * @format GUID
     */
    commentsWidgetId: string;
}
interface GetCommentsWidgetResponse {
    /** The retrieved CommentsWidget */
    commentsWidget?: CommentsWidget;
}
interface UpdateCommentsWidgetRequest {
    /** CommentsWidget to be updated, may be partial */
    commentsWidget: CommentsWidget;
}
interface UpdateCommentsWidgetResponse {
    /** The updated CommentsWidget */
    commentsWidget?: CommentsWidget;
}
interface DeleteCommentsWidgetRequest {
    /**
     * Id of the CommentsWidget to delete
     * @format GUID
     */
    commentsWidgetId: string;
    /** The revision of the CommentsWidget */
    revision?: string;
}
interface DeleteCommentsWidgetResponse {
}
interface QueryCommentsWidgetRequest {
    /** WQL expression */
    query: QueryV2;
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object.
     *
     * Learn more about the [filter section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-filter-section).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object.
     *
     * Learn more about the [sort section](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-sort-section).
     */
    sort?: Sorting[];
    /** Array of projected fields. A list of specific field names to return. If `fieldsets` are also specified, the union of `fieldsets` and `fields` is returned. */
    fields?: string[];
    /** Array of named, predefined sets of projected fields. A array of predefined named sets of fields to be returned. Specifying multiple `fieldsets` will return the union of fields from all sets. If `fields` are also specified, the union of `fieldsets` and `fields` is returned. */
    fieldsets?: string[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface QueryCommentsWidgetResponse {
    /** The retrieved CommentsWidgets */
    commentsWidgets?: CommentsWidget[];
    /** Paging metadata */
    metadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function registerCommentsWidget(): __PublicMethodMetaInfo<'POST', {}, RegisterCommentsWidgetRequest$1, RegisterCommentsWidgetRequest, RegisterCommentsWidgetResponse$1, RegisterCommentsWidgetResponse>;
declare function queryCommentsWidgetResources(): __PublicMethodMetaInfo<'POST', {}, QueryCommentsWidgetResourcesRequest$1, QueryCommentsWidgetResourcesRequest, QueryCommentsWidgetResourcesResponse$1, QueryCommentsWidgetResourcesResponse>;
declare function createCommentsWidget(): __PublicMethodMetaInfo<'POST', {}, CreateCommentsWidgetRequest$1, CreateCommentsWidgetRequest, CreateCommentsWidgetResponse$1, CreateCommentsWidgetResponse>;
declare function getCommentsWidget(): __PublicMethodMetaInfo<'GET', {
    commentsWidgetId: string;
}, GetCommentsWidgetRequest$1, GetCommentsWidgetRequest, GetCommentsWidgetResponse$1, GetCommentsWidgetResponse>;
declare function updateCommentsWidget(): __PublicMethodMetaInfo<'PATCH', {
    commentsWidgetId: string;
}, UpdateCommentsWidgetRequest$1, UpdateCommentsWidgetRequest, UpdateCommentsWidgetResponse$1, UpdateCommentsWidgetResponse>;
declare function deleteCommentsWidget(): __PublicMethodMetaInfo<'DELETE', {
    commentsWidgetId: string;
}, DeleteCommentsWidgetRequest$1, DeleteCommentsWidgetRequest, DeleteCommentsWidgetResponse$1, DeleteCommentsWidgetResponse>;
declare function queryCommentsWidget(): __PublicMethodMetaInfo<'POST', {}, QueryCommentsWidgetRequest$1, QueryCommentsWidgetRequest, QueryCommentsWidgetResponse$1, QueryCommentsWidgetResponse>;

export { type __PublicMethodMetaInfo, createCommentsWidget, deleteCommentsWidget, getCommentsWidget, queryCommentsWidget, queryCommentsWidgetResources, registerCommentsWidget, updateCommentsWidget };
